Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/ClusterM/flipperzero-firmware.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'lib/subghz/protocols/nice_flo.h')
-rw-r--r--lib/subghz/protocols/nice_flo.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/subghz/protocols/nice_flo.h b/lib/subghz/protocols/nice_flo.h
index f7d48dfa..0873e81b 100644
--- a/lib/subghz/protocols/nice_flo.h
+++ b/lib/subghz/protocols/nice_flo.h
@@ -83,13 +83,13 @@ uint8_t subghz_protocol_decoder_nice_flo_get_hash_data(void* context);
* Serialize data SubGhzProtocolDecoderNiceFlo.
* @param context Pointer to a SubGhzProtocolDecoderNiceFlo instance
* @param flipper_format Pointer to a FlipperFormat instance
* @param preset The modulation on which the signal was received, SubGhzPesetDefinition
* @return true On success
*/
bool subghz_protocol_decoder_nice_flo_serialize(
void* context,
FlipperFormat* flipper_format,
- SubGhzPesetDefinition* preset);
+ SubGhzPresetDefinition* preset);
/**
* Deserialize data SubGhzProtocolDecoderNiceFlo.
@@ -83,13 +83,13 @@ uint8_t subghz_protocol_decoder_nice_flo_get_hash_data(void* context);
* @param context Pointer to a SubGhzProtocolDecoderNiceFlo instance
* @param flipper_format Pointer to a FlipperFormat instance
- * @param preset The modulation on which the signal was received, SubGhzPesetDefinition
+ * @param preset The modulation on which the signal was received, SubGhzPresetDefinition
* @return true On success
*/